﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms.Design;
using System.Drawing;
using System.ComponentModel.Design;

namespace TGC.RadioButtonUtil.Design
{
    public class RadioButtonContainerDesigner : ParentControlDesigner
    {
        protected override void OnCreateHandle()
        {
            base.OnCreateHandle();
            RadioButtonContainer rbc = Control as RadioButtonContainer;
            if (rbc != null)
            {
                rbc.TabOrderChanged += new EventHandler(rbc_TabOrderChanged);
            }
        }

        protected override void OnDragDrop(System.Windows.Forms.DragEventArgs de)
        {
            // When a new RadioButton is added, the environment automatically checks one 
            // or more radio buttons, with respect to how the AutoCheck properties are set, 
            // and possibly to other factors. This may cause undesired behavior at design time.
            // This method may not be the right place to deal with it, but it works.

            Control.SuspendLayout();

            base.OnDragDrop(de);
            UpdateRadioButtons();

            Control.ResumeLayout(false);
        }

        private void rbc_TabOrderChanged(object sender, EventArgs e)
        {
            // Enables the designer to select the right button when the user alters the tab indices.
            // The buttons are actually reordered when the RadioButtonContainer is loaded.
            
            UpdateRadioButtons();
        }

        private void UpdateRadioButtons()
        {
            RadioButtonGroup g = ((RadioButtonContainer)Control).InternalGroup;

            System.Windows.Forms.RadioButton temp = g[0];
            for (int i = 0; i < g.Count; i++)
            {
                g[i].Checked = false;
                if (g[i].TabIndex < temp.TabIndex)
                    temp = g[i];
            }

            temp.Checked = true;
        }

        protected override void OnPaintAdornments(System.Windows.Forms.PaintEventArgs pe)
        {
            base.OnPaintAdornments(pe);

            // This makes the control's borders visible in the designer 
            // (in case that it has the same back color as it's parent)

            Pen blackDashPen = new Pen(Brushes.Black);
            blackDashPen.DashStyle = System.Drawing.Drawing2D.DashStyle.Dash;

            pe.Graphics.DrawRectangle(
                Pens.White,
                new Rectangle(Control.DisplayRectangle.X, Control.DisplayRectangle.Y,
                    Control.DisplayRectangle.Width - 1, Control.DisplayRectangle.Height - 1)
            );

            pe.Graphics.DrawRectangle(
                blackDashPen,
                new Rectangle(Control.DisplayRectangle.X, Control.DisplayRectangle.Y,
                    Control.DisplayRectangle.Width - 1, Control.DisplayRectangle.Height - 1)
            );

        }
    }
}
